@@ -85,7 +85,7 @@
 #' @author Lorenzo Busetto, phD (2019) - Inspired by 
 #'  function `getSentinel_query` of package 
 #'  [`getSpatialData`](https://github.com/16EAGLE/getSpatialData) by J. Schwalb-Willmann
-#' @author Luigi Ranghetti, phD (2019) \email{luigi@@ranghetti.info}
+#' @author Luigi Ranghetti, phD (2019)
 #' @references L. Ranghetti, M. Boschetti, F. Nutini, L. Busetto (2020).
 #'  "sen2r": An R toolbox for automatically downloading and preprocessing 
 #'  Sentinel-2 satellite data. _Computers & Geosciences_, 139, 104473. 
@@ -202,10 +202,10 @@ s2_list <- function(spatial_extent = NULL,
     time_interval <- as.Date(time_interval)
   }
   
-  if (anyNA(match(server, c("scihub", "gcloud")))) {
+  if (anyNA(match(server, c("scihub", "gcloud", "s2cogs")))) {
     print_message(
       type = "error",
-      "`server` must be \"scihub\" (and/or \"gcloud\" in a future release)"
+      "`server` must be \"gcloud\" or \"scihub\""
     )
   }
   
@@ -361,6 +361,28 @@ s2_list <- function(spatial_extent = NULL,
     out_dt_list[["gcloud"]][,server:=rep("gcloud", nrow(out_dt_list[["gcloud"]]))]
   }
   
+  ## AWS s2-COGs specific methods
+  if ("s2cogs" %in% server) {
+    if (eval(parse(text = 'requireNamespace("sen2r.addons", quietly = TRUE)'))) {
+      out_dt_list[["s2cogs"]] <- eval(parse(text = paste0(
+        "sen2r.addons::.s2_list_s2cogs(",
+        "  spatial_extent = spatial_extent,",
+        "  time_intervals = time_intervals,",
+        # "  s2bands = s2bands,", # TODO implement!
+        "  tile = tile,",
+        "  orbit = orbit,",
+        "  max_cloud = max_cloud,",
+        "  tmpdir = tmpdir",
+        ")"
+      )))
+    } else {
+      print_message(
+        type = "error",
+        "Please install package 'sen2r.addons' to use server = \"s2cogs\"."
+      )
+    }
+  }
+  
   ## Merge dt (in case of multiple servers)
   # order by the order of input "server" argument (this is used in duplicated:
   # first "server" value is taken in case of douplicated availability)
