@@ -1,8 +1,9 @@
 message("\n---- Test mask - main function ----")
 testthat::skip_on_cran()
-if (Sys.info()["sysname"] == "Windows") {
+if (Sys.info()["sysname"] != "Linux") {
   testthat::skip_on_ci() # TODO try to remove
 }
+skip_full_tests()
 
 # Required SAFE
 s2_l2a_list <- c(
